# API Reference

::: polars_iptools.iptools
    options:
      members:
        - is_valid
        - is_private
        - to_ipv4
        - to_address
        - to_string
        - extract_ips
        - extract_public_ips
        - extract_private_ips
        - is_in
        - ipv4_to_numeric
        - numeric_to_ipv4
        - extract_all_ips
        - IpExprExt
        - IpSeriesExt

## IP Extension Types

::: polars_iptools.types
    options:
      members:
        - IPv4
        - IPAddress

## GeoIP

::: polars_iptools.geoip

## Spur

::: polars_iptools.spur
